% To simplify for teaching, only conditions used in session A are kept.
% conditions: only [a,b] = [2,1; 2,8; 2,6] are kept
% For all condtions, especially b=6, no dichoptic border or irrelevant bar
% is presented since none of them is showed when I run the original scripts

%--- GetStimulus_FromCondition 
%--- list of conditions
%--- each condition is indexed by two indices: condition = [a, b]
%--- a: indicate the stimulus bars, relevant or irrelevant, (identified by index in AllCube(BarID, :, :) obtained in GetSmallCubes.m ) used in the stimlus, 
%--- b: the presentation mode (no irrelevant bar, binocular, left eye only, right eye only) of the irrelevant stimulus bars
% --- list for b below:
      %--- b = 1, no irrelevant stimulus bar, all relevant bars are presented binocularly, 
      %--- b = 2, 3, 4, binocular, dichoptic checker board pattern, uniform
      %monocular pattern, respectively, presentation of the irrelevant bar
      % --- b = 5 (Added May 8, 2007)--- no irrelevant stimulus bars, but each relevant bar is
      % presented monocularly such that there is a vertical border between
      % the left eye presented and right eye presented bars and this border
      % is at the opposite side of the orientation contrast border.  
      %---- b=6 (added May 8th, 2007) --- like 5, but dichoptic border
      %coincides with the orientation contrast border.
      %--- b = 7  (Added May 8, 2007) --- no irrelevant stimulus bars, but each relevant bar is
      % presented monocularly such that the left and right eye origin form
      % a checker board pattern.
      %--- b = 8 (added May 8th, 2007)  --- no irrelevant bars, but only
      %one eye sees all the relevant bar.
      %--- b = 9 --- irrelevant bars presented binocularly, but in a
      %spatial checkerboard pattern of blanks and irrelevant bars.
      %--- b = 10 --- irrelevant bars presented monocularly to one eye only,
      % with a checkerboard pattern of blanks and irrelevant bars.
 %--- list for a below:    
    % --- a = 1:   relevant stimulus: left tilt (BarID = 1) vs right tilt (BarID = 2) bars of
    % SmallAngle from vertical, 
                 %-irrlevant stimulus: on all bars, uniformly left (BarID = 3) (or right tilt (BarID = 4) ) bars of
                 %------SmallAngle from horizontal.
    % --- a = 2:   same as a =1, except that SmallAngle tilt is from horizontal  with BarID = 3, 4 (vertical, with BarID = 1, 2) for relevant (irrelevant) bars.
    % --- a = 3, 4:  same as a = 1 (for a=3), 2 (for a=4), except that the
                     % tilt angle is LargeAngle = 2*SmallAngle.
    %---  a = 5, 6, 7, 8: same as a = 1, 2, 3, 4 respectively, except that
                          %--- the irrelevant bars are horizontal with BarID = 11 (for a =
                          %5 or 7, or vertical with BarID = 12  for a = 6, 8.

%for visual search task only.

%%
%--- StimulusContent(:, j, i) describe the identities (which is first index in the array AllCubes) of the two bars at
%grid location (j, i); This definition means that each grid location has no more
% than 2 bars. If the identity is 0, this means
% no bar. So at one location, it can have no bar, one bar,
% or two bars. So if StimulusContent(:, j, i) =
% (1, 2), it means at this location bars 1 and 2 are
% present.                          
StimulusContent = zeros(2, params.stim.NbY, params.stim.NbX);

%   StimulusPresentationMode(a, j, i) = 1, 2, 3 describe the mode in
%which the bar indicated by StimulusContent(a, j, i) is presented, in binocular, left eye only, or right eye only.
StimulusPresentationMode =  zeros(2, params.stim.NbY, params.stim.NbX); 

%--- First generate the task-relevant stimulus from condition index
secondconditionindex = condition(2);
randx = (rand>0.5);
BarID_Target = 1+randx;
BarID_Background = 2-randx;


StimulusContent(1, :, :) = BarID_Background*ones(1, params.stim.NbY, params.stim.NbX);
StimulusContent(1, TargetVerticalPosition, TargetHorizontalPosition) = BarID_Target;

if secondconditionindex == 1  %--- All bars are presented binocularly
    StimulusPresentationMode(1, :, :) = ones(params.stim.NbY, params.stim.NbX);
elseif secondconditionindex == 6  %--- Target bar and other bars are presented dichopticly
    
    DichopticTargetVPosition = TargetVerticalPosition;
    DichopticTargetHPosition = TargetHorizontalPosition;
    randx = (rand>0.5);
    
    StimulusPresentationMode(1, :, :) = (3-randx)*ones(1, params.stim.NbY, params.stim.NbX);
    StimulusPresentationMode(1, DichopticTargetVPosition,  DichopticTargetHPosition) = (2+randx);
    
elseif  secondconditionindex == 8  %--- All bars are persented monocularly
    randx = (rand>0.5);
    StimulusPresentationMode(1, :, :) = 2*randx + 3*(1-randx);
else
    'no such condition'
    return;
end
%--- Second generate the task-irrelevant stimulus
% here in this session we have no irrelevant stimulus, so just leave it all zeros.
StimulusContent(2, :, :) = zeros(params.stim.NbY, params.stim.NbX);
















